.. nxstools documentation master file, created by
   sphinx-quickstart on Thu Apr 21 11:49:59 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents
========

.. toctree::
   :maxdepth: 2

   nxscollect
   nxsconfig
   nxscreate
   nxsdata
   nxsfileinfo
   nxsetup
   nxstools
       
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
